{ config, pkgs, ... }:

let
  colors = import ../colors;
in
{
  services = {
   xserver = {
      enable = true;
      libinput = {
        enable = true;
        touchpad.tapping = true;
      };
      xkbOptions = "caps:escape";
      displayManager = {
        lightdm = {
          enable = true;
          greeters.gtk = {
            enable = true;
            theme = {
              name = "Nordic";
              package = pkgs.nordic;
            };
          };
          background = ../wallpapers/${colors.wallpaper};
        };
        defaultSession = "none+i3";
      };
      windowManager.i3 = {
        enable = true;
        package = pkgs.i3-gaps;
      };
    };
    udev.packages = [ pkgs.yubikey-personalization ];
    pcscd.enable = true;
    gnome.gnome-keyring.enable = true; # For remembering nextcloud login, among other things
  };

  environment.systemPackages = with pkgs; [ yubioath-flutter ];

  # Enable OpenTabletDriver, GUI configurator is otd-gui
  hardware.opentabletdriver.enable = true;

  # To prevent `Unit dconf.service not found.` after theming GTK in HM
  programs.dconf.enable = true;

  sound.enable = true;
  hardware.pulseaudio.enable = true;
  nixpkgs.config.pulseaudio = true;

  fonts.fonts = with pkgs; [
    noto-fonts
    noto-fonts-cjk
    (nerdfonts.override { fonts = [ "FiraCode" ]; }) # required for icons
  ];
}
